summary refs log tree commit diff stats
path: root/lib/system.nim
diff options
context:
space:
mode:
Diffstat (limited to 'lib/system.nim')
-rw-r--r--lib/system.nim6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/system.nim b/lib/system.nim
index 605670f44..559c71f01 100644
--- a/lib/system.nim
+++ b/lib/system.nim
@@ -3122,14 +3122,14 @@ when not defined(createNimHcr) and not defined(nimscript):
   include nimhcr
 
 when notJSnotNims and not defined(nimSeqsV2):
-  proc prepareStrMutation*(s: var string) {.inline.} =
+  proc prepareMutation*(s: var string) {.inline.} =
     ## String literals (e.g. "abc", etc) in the ARC/ORC mode are "copy on write",
     ## therefore you should call `prepareStrMutation` before modifying the strings
     ## via `addr`.
     runnableExamples("--gc:arc"):
       var x = "abc"
       var y = "defgh"
-      prepareStrMutation(y) # without this, you may get a `SIGBUS` or `SIGSEGV`
+      prepareMutation(y) # without this, you may get a `SIGBUS` or `SIGSEGV`
       moveMem(addr y[0], addr x[0], x.len)
       assert y == "abcgh"
     discard
@@ -3122,14 +3122,14 @@ when not defined(createNimHcr) and not defined(nimscript):
     ## String literals (e.g. "abc", etc) in the ARC/ORC mode are "copy on write",
-    ## therefore you should call `prepareStrMutation` before modifying the strings
+    ## therefore you should call `prepareMutation` before modifying the strings
     ## via `addr`.
     runnableExamples("--gc:arc"):